;; alteres calibration coefficients (Zy, Sy, Ox) to show influence on magnitude and fft

@userlib.pro
;-------------------------------------------------------------------------
pro b2,dZz,dSy,dOxz,dOyz
;-------------------------------------------------------------------------
common data
inpf='b_uncal.txt'
fnam='ex_b2_'
if n_elements(dZz) eq 0 then begin
    print,'USAGE: b2,dZz,dSy,dOxz,dOyz'
    print,'....using default: b2,0,0,0,0'
   dZz=0.d0 & dSy=dZz & dOxz=dZz & dOyz=dZz
   endif

;; READ uncal
read_input,t,b,nli,inpf
b0=b(0:2,*)
bmag0=magn(b0) & nr=n_elements(bmag0)

;; Apply calibration
@calib_param_b.txt
print,'INITIAL calibration:'
print,calm
bcalib=bcal(calm)
bmagf=magn(bcalib)

;; CHANGE calibration parameters
errs=[dZz,dSy,dOxz,dOyz]
which=where(errs ne 0,nerr)
tit=''
comments=['Offset error Zz','Scaling error Sy','Orthogonality error Oxz','Orthogonality error Oyz']
if  nerr gt 0 then begin
calm(2,0)=calm(2,0)+dZz*1.d0 ; offset Zz 0.2 (1.2)
calm(1,2)=calm(1,2)+dSy*1.d0 ; scaling Sy 0.02
calm(0,3)=calm(0,3)+dOxz*1.d0 ;orth to spin_axis 0.02
calm(1,3)=calm(1,3)+dOyz*1.d0 ;orth in spin_plane 0.02
print,'CHANGED Calibration parameters:'
print,calm

;; Apply wrong calibration
bbad=bcal(calm)
bmagb=magn(bbad)
fnam=fnam+string(which(0),format="(i1)")
tit=comments(which(0))
if nerr eq 2 then begin
    fnam=fnam+string(which(1),format="(i1)")
    tit=tit+' and '+comments(which(1))
    endif
bmag0=bmagb
endif

;; PLOT magnitudes
window,0 & !p.multi=[0,1,3] & red=120
yr=[min([bmag0,bmagf]),max([bmag0,bmagf])]
plot,t,bmag0,/xsty,charsize=1.2,yrange=yr,$
    xtitle='hours',ytitle='B_cal(red), B_uncal [nT]',title=tit
oplot,t,bmagf,color=red

;; Compute sample_rate & define frequencies
dt=t-shift(t,1)
sampling=mean(dt(where(dt gt 0)))*3600.d0
frqreso=1.d0/nr/sampling
freq=findgen(nr/2)*frqreso

;; PLOT FFT of magnitudes
fft0=fft(bmag0-mean(bmag0),-1,/double)
fftf=fft(bmagf-mean(bmagf),-1,/double)
fftc=fft(b(1,*)-mean(b(1,*)),-1,/double)
spin=max(abs(fftc(0:nr/2-1))^2,ma)
spinfrq=freq(ma)
yr=[1.0e-10,1.0e5]
plot,freq,abs(fft0(0:nr/2-1))^2,/ylog,xrange=[0,2.],/xsty,$
    yrange=yr,ytitle='power_sp_B_uncal [nT^2/Hz]',xtitle='freq [Hz]',title=tit
plots,[spinfrq,spinfrq],[yr(0),1.e-5],line=2,color=red
plots,[2*spinfrq,2*spinfrq],[yr(0),1.e-5],line=2,color=red
plot,freq,abs(fftf(0:nr/2-1))^2,/ylog,xrange=[0,2.],/xsty,$
    yrange=yr,ytitle='power_sp_B_cal [nT^2/Hz]',xtitle='freq [Hz]'
plots,[spinfrq,spinfrq],[yr(0),1.e-5],line=2,color=red

;; Save plot
write_png,fnam+'_fft.png',tvrd()
end
